<head>
<title>Using David Taylor's Active-X DLL Satellite Component</title>
</head>

<p><font face="Arial" size="2">This page demonstrates calling the SGP4 component active-X DLL from a Web page.</font></p>
<hr size="0">

<h3><font face="Arial">Creating and Destroying the object</font></h3>
<p><font face="Arial" size="2">First we try and instantiate the component and
check for a correct result.&nbsp; Display an error message if there is a
problem:</font></p>
<blockquote>
<pre><font COLOR="#800000">&lt;%
On Error Resume Next
Set objSatList = Server.CreateObject (&quot;DJTSatLib.Satellites&quot;)
If IsObject (objSatList) Then
	... do things with the object ....
Else
	... display error message ....
End If
%&gt;</font></pre>
</blockquote>
<p><font face="Arial" size="2">Finally free the component we have created (if
any)</font></p>
<blockquote>
<pre><font color="#800000">&lt;% Set objSatList = Nothing %&gt;</font></pre>
</blockquote>
<hr size="0">
<h3><font face="Arial">&nbsp;Using the Satellite List object</font></h3>

<p><font face="Arial" size="2">Load the Kepler 2-line element data files by
setting the KeplerPath variable.&nbsp; You <b>must</b> do this to get some data
into the satellite list.</font></p>
<blockquote>
<pre><font color="#800000">objSatList.KeplerPath = &quot;C:\KeplerData&quot;</font></pre>
</blockquote>
<p><font face="Arial" size="2">Define the location of the observer.  This is required for any pass predictions.</font></p>
<blockquote>
<pre><font color="#800000">objSatList.ObsLat = 55.9	' degrees
objSatList.ObsLon = -3.2	' degrees
objSatList.ObsHeight = 180	' metres</font></pre>
</blockquote>
<p>

<font face="Arial" size="2">Define the day we want to start at, note all times
are UTC</font></p>
<blockquote>
<pre><font color="#800000">start = DateSerial (2000, 2, 3)	' 2000, Feb, 3
days = 1			' number of days to predict
min_elevation = 2		' degrees above the horizon
min_seconds = 300		' required min pass duration</font></pre>
</blockquote>
<p><font face="Arial" size="2">Generate a pass-list for the period.  You get all the passes as a comma-separated list.</font></p>
<blockquote>
<pre><font color="#800000">passes = objSatList.PassListForPeriod _
             (&quot;NOAA 15&quot;, start, min_seconds, days, min_elevation)</font></pre>
</blockquote>
<p><font face="Arial" size="2">Strip out the quotation marks from the returned list.  These will be around the satellite names that have spaces in them.</font></p>
<blockquote>
<pre><font color="#800000">passes = Replace (passes, Chr(34), &quot;&quot;)</font></pre>
</blockquote>
<p><font face="Arial" size="2">Split the comma-separated list into an array</font></p>
<blockquote>
<pre><font color="#800000">pass_array = Split (passes, &quot;,&quot;, -1)</font></pre>
</blockquote>
<p><font face="Arial" size="2">Iterate over the list, returning it as an HTML table to the caller</font></p>
<blockquote>
<pre><font color="#800000">Response.Write &quot;&lt;table border=1 cellpadding=2 cellspacing=0&gt;&quot;</font></pre>
<pre><font color="#800000">For Each pass In pass_array
  Response.Write &quot;&lt;tr&gt;&lt;td&gt;&lt;pre&gt;&quot; &amp; pass &amp; &quot;&lt;/pre&gt;&lt;/td&gt;&lt;/tr&gt;&quot;
Next</font></pre>
<pre><font color="#800000">Response.Write &quot;&lt;/table&gt;&quot;</font></pre>
</blockquote>
<hr size="0">
<h3><font face="Arial">The Results</font></h3>
<p><font face="Arial" size="2">Here are the results from running the ASP code
show above:</font></p>
<%
On Error Resume Next
Set objSatList = Server.CreateObject ("DJTSatLib.Satellites")
If IsObject (objSatList) Then
Else
%>
  <p align="center"><font face="Arial" size="2"><b>
Active server pages failed to create Satellite List object<br>
  Please ensure you have run the command:</b></font></p>
<div align="center">
  <center>
  <pre>REGSVR32 DJTSatLib.dll</pre>
  </center>
</div>
  <p align="center"><font face="Arial" size="2"><b>from the folder containing DJTSatLib.dll</b></font>
<%
End If

objSatList.KeplerPath = "C:\Davids\Delphi4\Radio\WXtrack\Source"
' Define the location of the observer
objSatList.ObsLat = 55.9		' degrees
objSatList.ObsLon = -3.2		' degrees
objSatList.ObsHeight = 180		' metres

' Define the day we want to start at, note all times are UTC
start = DateSerial (2001, 2, 3)		' 2001, Feb, 3
days = 1				' number of days to predict
min_elevation = 2			' degrees above the horizon
min_seconds = 300			' required min pass duration

' Generate a pass-list for the period
passes = objSatList.PassListForPeriod _
		("NOAA 15", start, min_seconds, days, min_elevation)

' Strip out the quotation marks for a better display
passes = Replace (passes, Chr(34), "")

' Split the comma-separated list into an array
pass_array = Split (passes, ",", -1)

' Iterate over the list, returning it as an HTML table to the caller
Response.Write "<table border=1 cellpadding=2  cellspacing=0>"
For Each pass In pass_array
  Response.Write "<tr><td>" & pass & "</td></tr>"
Next
Response.Write "</table>"

Set objSatList = Nothing 
%>
