unit TestForm;

{
2001 Jan 07  First version
             Correct for extra parameter Phase returned from IsVisible
2001 Jan 08  Update for Range, RangeRate and Alitude being returned
2001 Sep 08  Update version number info to 3.1.2.19
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DJTSatLib_TLB, StdCtrls, ComCtrls, ExtCtrls;

type
  TFormMain = class (TForm)
    LabelVersion: TLabel;
    LabelKeplerPath: TLabel;
    ListBoxSatNames: TListBox;
    LabelNames: TLabel;
    LabelLocation: TLabel;
    ListBoxPasses: TListBox;
    LabelPasses: TLabel;
    ButtonMakePasses: TButton;
    LabelChoose: TLabel;
    DateTimePickerDate: TDateTimePicker;
    EditSatellite: TEdit;
    DateTimePickerTime: TDateTimePicker;
    LabelUTC: TLabel;
    LabelSatVisible: TLabel;
    ButtonClose: TButton;
    LabelSunMoonVisible: TLabel;
    LabelPassDetails: TLabel;
    CheckBoxRealTime: TCheckBox;
    TimerRealTime: TTimer;
    Bevel1: TBevel;
    Bevel2: TBevel;
    Bevel3: TBevel;
    DateTimePickerPasses: TDateTimePicker;
    LabelPassDate: TLabel;
    procedure FormCreate (Sender: TObject);
    procedure FormDestroy (Sender: TObject);
    procedure ButtonMakePassesClick (Sender: TObject);
    procedure ListBoxSatNamesClick (Sender: TObject);
    procedure FormShow (Sender: TObject);
    procedure DateTimePickerDateChange (Sender: TObject);
    procedure ButtonCloseClick (Sender: TObject);
    procedure CheckBoxRealTimeClick (Sender: TObject);
    procedure TimerRealTimeTimer (Sender: TObject);
  private
    { Private declarations }
    ISat: ISatellites;
    procedure date_time_changed;
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

uses
  ComObj;

{$R *.DFM}

const
  latitude = 56.0;
  longitude = -3.2;
  obs_height = 180.0;
  expected = 'Lon: -3.2  Lat: 56  Height: 180';


function NowUTC: TDateTime;
var
  system_datetime: TSystemTime;
begin
  GetSystemTime (system_datetime);
  Result := SystemTimeToDateTime (system_datetime);
end;


procedure TFormMain.FormCreate (Sender: TObject);
begin
  try
    // Try and connect to the Active-X DLL
    ISat := CreateComObject (CLASS_Satellites) as Satellites;
  except
  end;

  if Assigned (ISat)
  then
    begin
    // Get the DLL version information string
    LabelVersion.Caption := 'DLL version: ' + ISat.VersionString;
    // Tell the DLL to read the Kepler files in the folder named
    ISat.KeplerPath := 'C:\Davids\Delphi5\Radio\WXtrack\Source\';
    // and find out how many satellites were found
    LabelKeplerPath.Caption := 'Kepler path: ' + ISat.KeplerPath +
        '  which contains ' + IntToStr (ISat.SatCount) + ' satellites';
    // Get comma-separated list of the satellite names
    ListBoxSatNames.Items.CommaText := ISat.SatNames;
    // Try setting and reading back the observer location
    ISat.ObsLon := longitude;
    ISat.ObsLat := latitude;
    ISat.ObsHeight := obs_height;
    LabelLocation.Caption := Format
       ('Location:  Lon = %f  Lat = %f  Height = %f  (expected %s)',
        [ISat.ObsLon, ISat.ObsLat, ISat.ObsHeight, expected]);
    end
  else
    begin
    ShowMessage ('Error connecting to in-process COM server DJTSatLib.dll' + #13 + #13 +
                 'Try using the command "REGSVR32 DJTSatLib.dll" ' +
                 'from the command prompt in the folder containing ' +
                 'the file DJTSatLib.dll.' + #13 + #13 +
                 'The REGSVR32 command may be found in your Windows System folder.');
    end;
end;


procedure TFormMain.FormDestroy (Sender: TObject);
begin
  if Assigned (ISat) then
    begin
    ISat.KeplerPath := '';
    ISat := nil;
    end;
end;


procedure TFormMain.FormShow (Sender: TObject);
begin
  DateTimePickerDate.DateTime := NowUTC;
  DateTimePickerTime.DateTime := NowUTC;
  DateTimePickerPasses.DateTime := NowUTC;
  ButtonMakePasses.Click;
  date_time_changed;
end;


procedure TFormMain.ButtonMakePassesClick (Sender: TObject);
begin
  ListBoxPasses.Items.CommaText := ISat.PassListForPeriod (
    EditSatellite.Text,
    DateTimePickerPasses.DateTime,
    120, 2, 1.5);
end;


procedure TFormMain.ListBoxSatNamesClick (Sender: TObject);
var
  index: integer;
begin
  index := ListBoxSatNames.ItemIndex;
  if index = -1 then Exit;
  EditSatellite.Text := ListBoxSatNames.Items.Strings [index];
end;


procedure TFormMain.DateTimePickerDateChange (Sender: TObject);
begin
  date_time_changed;
end;


procedure TFormMain.date_time_changed;
const
  Rad2Deg = 180 / pi;
var
  utc: TDateTime;
  jt: double;
  sat: string;
  is_visible: WordBool;
  southbound: WordBool;
  az, el, lon, lat, phase: double;
  st: string;
  range, range_rate, altitude: double;
begin
  utc := Trunc (DateTimePickerDate.DateTime) +
         Frac (DateTimePickerTime.DateTime);
  jt := ISat.DateTimeToJT (utc);
  sat := EditSatellite.Text;
  is_visible := ISat.IsVisible (sat, jt, 0.5, southbound, az, el, lon, lat,
                                range, range_rate, altitude, phase);
  if is_visible
    then st := sat + ' is visible'
    else st := sat + ' is not visible';
  LabelPassDetails.Caption := Format
    ('Az:%1f  El:%.1f   Lon:%.1f  Lat:%.1f   ' +
     'Range:%0.fkm  Range rate:%.1fkm/s  Altitude:%.0fkm',
    [Rad2Deg*az, Rad2Deg*el, Rad2Deg*lon, Rad2Deg*lat, range, range_rate,
     altitude]);
  LabelSatVisible.Caption := st;
  if ISat.IsVisible ('SUN', jt, 0.5, southbound, az, el, lon, lat, range, range_rate, altitude, phase)
    then st := 'SUN is visible, '
    else st := 'SUN is not visible, ';
  if ISat.IsVisible ('MOON', jt, 0.5, southbound, az, el, lon, lat, range, range_rate, altitude, phase)
    then LabelSunMoonVisible.Caption := st + 'MOON is visible'
    else LabelSunMoonVisible.Caption := st + 'MOON is not visible';
end;


procedure TFormMain.ButtonCloseClick (Sender: TObject);
begin
  Close;
end;


procedure TFormMain.CheckBoxRealTimeClick (Sender: TObject);
begin
  TimerRealTime.Enabled := CheckBoxRealTime.Checked;
end;


procedure TFormMain.TimerRealTimeTimer (Sender: TObject);
begin
  TimerRealTime.Enabled := False;
  DateTimePickerDate.DateTime := NowUTC;
  DateTimePickerTime.DateTime := NowUTC;
  date_time_changed;
  TimerRealTime.Enabled := CheckBoxRealTime.Checked;
end;

end.

